import GObject from 'gi://GObject'
import GLib from 'gi://GLib'
import St from 'gi://St';
import Meta from 'gi://Meta';
import Shell from 'gi://Shell';
import Gio from 'gi://Gio';

import * as Main from 'resource:///org/gnome/shell/ui/main.js';
import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';

import {Extension} from 'resource:///org/gnome/shell/extensions/extension.js';

import {Overlay} from './Overlay.js';
import * as Utils from './Utils.js';

let overlay;

export default class BianbuChatExtension extends Extension {
    enable() {
        // indicator in the status-menu
        this._indicator = new PanelMenu.Button(0.0, "ChatGPT", false);
        this._settings = this.getSettings('org.gnome.shell.extensions.etixsoftware.openai');

        let hbox = new St.BoxLayout({
            style_class: 'panel-button',
        });

        let gicon = Gio.Icon.new_for_string(this.path + "/icons/chatgpt_icon.png");
        const icon = new St.Icon({
          gicon
        });
        hbox.add_child(icon);
        this._indicator.add_child(hbox);
        let menuItemToggle = new PopupMenu.PopupMenuItem("Toggle");
        this._indicator.menu.addMenuItem(menuItemToggle);
        menuItemToggle.connect("activate", this._onTogglePress.bind(this));

        let menuItemPrefs = new PopupMenu.PopupMenuItem("Settings");
        this._indicator.menu.addMenuItem(menuItemPrefs);
        menuItemPrefs.connect("activate", this._onPrefsPress.bind(this));

        Main.panel.addToStatusArea("ChatGptIndicator", this._indicator, 1);

        // the overlay which opens when shortcut is pressed
        overlay = new Overlay();
        overlay.hide();

        let settings = Utils.getSettings();

        // register shortcut
        Main.wm.addKeybinding("shortcut-toggle-overlay", settings,
            Meta.KeyBindingFlags.NONE,
            Shell.ActionMode.NORMAL,
            this._onTogglePress.bind(this));
    }

    disable() {
        this._indicator.destroy();
        overlay.destroy();

        this._indicator = null;
        overlay = null;

        this._settings = null;
        Main.wm.removeKeybinding("shortcut-toggle-overlay");
    }

    _onTogglePress() {
        if (overlay.isVisible()) {
            overlay.hide();
        } else {
            overlay.show();
        }
    }

    _onPrefsPress() {
        this.openPreferences();
    }

}
